@@ -24,7 +24,7 @@ class Experimento:
     def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10, cantidad_columnas=10,
                  procesar_tiempo_archivo_irregular=False, puntos_importantes=None, objeto_a_promediar=1,
                  tamanio_intervalo_para_promedio=100, genera_matriz_recurrencia=False, regiones_preferidas=None,
-                 distancia_max_para_volumenes=24, division_de_dist_max=2):
+                 genera_regiones_preferidas=True, distancia_max_para_volumenes=24, division_de_dist_max=2):
         self.nombre_archivo = nombre_archivo
         print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
         self.dimension_caja = dimension_caja
@@ -214,7 +214,7 @@ class Experimento:
                             self.posiciones_y.max())
 
         self.realiza_procesamiento_MOTUS(objeto_a_promediar, tamanio_intervalo_para_promedio,
-                                         genera_matriz_recurrencia)
+                                         genera_matriz_recurrencia, genera_regiones_preferidas)
 
         """
         self.reduce_elementos_sesion_con_modulo(tamanio=tamanio_de_subsucesiones,
@@ -1592,7 +1592,7 @@ class Experimento:
             if getattr(sys, 'frozen', False):
                 os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
 
-            data_array = np.array(np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas))
+            data_array = np.array(np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas))
 
             print(data_array)
 
